<?php

/**
 * @file
 * ONKI configuration UI.
 */

/**
 * Implements hook_admin_settings_form().
 */
function onki_admin_settings_form($form, &$form_state) {
  $form = array();

  $form['onki_global_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('ONKI Configuration'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['onki_global_settings']['onki_domain'] = array(
    '#type' => 'textfield',
    '#title' => t('ONKI domain'),
    '#description' => t('URL for connecting to ONKI Web Service API V2. See !link. <br />Ex. <em>http://onki.fi/</em>', array('!link' => l(t('the API documentation'), 'http://onki.fi/api/v2/http/'))),
    '#default_value' => variable_get('onki_domain', 'http://onki.fi/'),
    '#disabled' => FALSE,
    '#size' => 100,
    '#maxlength' => 512,
  );

  $form['onki_global_settings']['onki_parameters_v2'] = array(
    '#type' => 'textfield',
    '#title' => t('ONKI parameters'),
    '#description' => t('URL for connecting to ONKI Web Service API V2. See !link. <br />Ex. <em>key-[ONKI_KEY]/api/v2/http/[METHOD_GROUP]/[METHOD_NAME]?[PARAMETERS]</em>', array('!link' => l(t('the API documentation'), 'http://onki.fi/api/v2/http/'))),
    '#default_value' => variable_get('onki_parameters_v2', 'key-[ONKI_KEY]/api/v2/http/[METHOD_GROUP]/[METHOD_NAME]?[PARAMETERS]'),
    '#disabled' => FALSE,
    '#size' => 100,
    '#maxlength' => 512,
  );

  $form['onki_global_settings']['onki_api_version'] = array(
    '#type' => 'select',
    '#title' => t('Select used API version'),
    '#description' => t('The used ONKI API version. See !link. Currently only V2 is supported.', array('!link' => l(t('the documentation for the APIs'), 'http://onki.fi/api/'))),
    '#default_value' => variable_get('onki_api_version', ONKI_DEFAULT_API_VERSION),
    '#options' => array(
      '2' => t('ONKI API V2'),
    ),
  );

  $form['onki_global_settings']['onki_autocomplete_result_count'] = array(
    '#type' => 'textfield',
    '#title' => t('Autocomplete result count'),
    '#description' => t('Define the maximum count of autocomplete results to be shown. Any number between 5 and 30 is a good choice.'),
    '#default_value' => variable_get('onki_autocomplete_result_count', ONKI_DEFAULT_RESULT_COUNT),
    '#size' => 2,
  );

  $form['onki_global_settings']['onki_result_language'] = array(
    '#type' => 'select',
    '#title' => t('Results language'),
    '#description' => t('Define the language for the results.'),
    '#default_value' => variable_get('onki_result_language', ONKI_DEFAULT_LANGUAGE),
    '#options' => array(
      'fi' => t('Finnish'),
      'sv' => t('Swedish'),
      'en' => t('English'),
    ),
  );

  $form['onki_global_settings']['onki_vocabulary'] = array(
    '#type' => 'textfield',
    '#title' => t('ONKI vocabulary name'),
    '#description' => t('Give ONKI vocabulary name. Ex. <em>yso, allars, koko, etc.</em>. <strong>Koko covers all ontologies</strong>.'),
    '#default_value' => variable_get('onki_vocabulary', ONKI_DEFAULT_VOCABULARY),
    '#size' => 5,
  );

  $form['onki_global_settings']['onki_method_name'] = array(
    '#type' => 'textfield',
    '#title' => t('ONKI method name'),
    '#description' => t('Give ONKI method name. See methods from the API !link. For most cases <strong>search</strong> is a valid choice here.', array('!link' => l(t('documentation'), 'http://onki.fi/api/'))),
    '#default_value' => variable_get('onki_method_name', 'search'),
    '#size' => 5,
  );

  $form['onki_global_settings']['onki_access_key'] = array(
    '#type' => 'textfield',
    '#title' => t('ONKI Access Key'),
    '#description' => t('Signup key for using ONKI Web Service. See !link. The key is dependent on your IP address.', array('!link' => l(t('the signup page'), 'http://onki.fi/en/signup/'))),
    '#default_value' => variable_get('onki_access_key', ''),
    '#size' => 40,
  );

  $form['onki_global_settings']['onki_query_cache_ttl'] = array(
    '#type' => 'select',
    '#title' => t('Cache lifetime'),
    '#description' => t('The time-to-live value for query responses from ONKI.'),
    '#default_value' => variable_get('onki_query_cache_ttl', '86400'),
    '#options' => array(
      0 => t('No cache'),
      500 => t('5 min'),
      3600 => t('1 hour'),
      86400 => t('24 hours'),
      604800 => t('7 days'),
    ),
  );

  $form['onki_global_settings']['onki_autocomp_min_strlen'] = array(
    '#type' => 'select',
    '#title' => t('Minimum string length'),
    '#description' => t('The minimum length for autocompletion queries.'),
    '#default_value' => variable_get('onki_autocomp_min_strlen', 2),
    '#options' => array(
      1 => 1,
      2 => 2,
      3 => 3,
      4 => 4,
      5 => 5,
      6 => 6,
      7 => 7,
    ),
  );

  $field_info = taxonomy_get_vocabularies();
  $field_choices = array('0' => t('--none--'));
  foreach ($field_info as $field) {
    $key = $field->vid;
    $value = $field->name;
    $field_choices[$key] = $value;
  }

  $form['onki_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('ONKI integration'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $field_choices = array('0' => t('--none--'));
  $field_info = field_info_instances('node');
  foreach ($field_info as $node_type => $fields) {
    foreach ($fields as $key => $field) {
      $field_choices[$key] = $field['label'];
    }
  }

  $form['onki_settings']['onki_fields'] = array(
    '#type' => 'select',
    '#options' => $field_choices,
    '#multiple' => TRUE,
    '#size' => 10,
    '#title' => t('Fields'),
    '#description' => t('jQuery selector for the text elements where autocomplete is needed.'),
    '#default_value' => variable_get('onki_fields', array('field_tags' => 'field_tags')),
  );

  $options = array('0' => t('--none--'));
  $types = node_type_get_types();
  foreach ($types as $code_name => $info) {
    $options[$code_name] = $info->name;
  }

  $form['onki_settings']['onki_content_types'] = array(
    '#type' => 'select',
    '#options' => $options,
    '#multiple' => TRUE,
    '#size' => 10,
    '#title' => t('Content types'),
    '#description' => t('Select which content types are supported by Onki.'),
    '#default_value' => variable_get('onki_content_types', array('article')),
  );

  return system_settings_form($form);
}
