(function ($) {

  Drupal.Onki = {};
  Drupal.Onki.values = new Array();

  no_terms = false;
  Drupal.behaviors.onki = {

    attach: function(context) {
      // Onki_autocomplete_fake_btn defined in the form_alter().
      Drupal.behaviors.onki.fixAutocompleteEvents();
      $fakeField = $('#onki_autocomplete_fake');
      $theRealField = $('.onki_real_term_field input.form-text');
      $niceTermCont = $('#onki-tags-container');

      if (no_terms == false) {
        $('<div id="onki-nice-term-wrapper"></div>').insertAfter($niceTermCont);
        no_terms = true;
      }

      // Check if the field exists at all before the length
      // statement because lenght cannot be taken from undefined.
      if (Drupal.Onki.values) {
        // Editing existing node needs values read from "real field"
        // and processed for "nice field" and made visible.
        if (Drupal.Onki.values.length < 1) {
          existingUris = $theRealField.attr('value').split(/,[\s]?/);
          for (u in existingUris) {
            if (existingUris[u].trim()) Drupal.Onki.values[existingUris[u]] = {};
          }
        }
      }
      for (uri in Drupal.Onki.values) {
        existingUris = onkiGetNiceTerms();
        if(jQuery.inArray(uri, existingUris) != -1) {
          return false;
        }
        Drupal.behaviors.onki.insertNiceElem(uri);
        Drupal.behaviors.onki.loadInfo(uri, Drupal.behaviors.onki.updateNiceElems);
      }

      $fakeField.keydown(function(e) {
        if (e.keyCode == 13) {
          //Prevent the submit button from firing when 'return' is pressed.
          e.preventDefault();
          return false;
        }
      });

      $("input#onki_autocomplete_fake").bind('autocompleteSelect', function(event) {
        // Get the URI value. At this point this
        // can be ONKI URI or new term.
        uri = $fakeField.attr('value').trim();
        // Check if empty (after trimming) string is entered.
        if (uri == '') {
          return false;
        }
        // empty the field itself
        $fakeField.attr('value', '');

        // check if we're trying to add an uri that is already added
        existingUris = onkiGetNiceTerms();
        if(jQuery.inArray(uri, existingUris) != -1) {
          alert(Drupal.t('Term already added!'));
          return false;
        }
        // If the URI doesn't contain http:// it is incomplete, return false
        if (uri.search('http://') == -1) {
          return false;
        }

        Drupal.Onki.values[uri] = '';

        Drupal.behaviors.onki.insertNiceElem(uri);
        Drupal.behaviors.onki.loadInfo(uri, Drupal.behaviors.onki.updateNiceElems);

        // Do not execute click event.
        //return false;
      });

      $theRealField.closest('form').submit(function() {
        Drupal.behaviors.onki.submit($theRealField);
      });
    },

    loadInfo: function(uri, callback) {
      url = Drupal.settings.basePath + 'onki/json/concepttree';
      $.post(
        url,
        {uri: uri},
        function(data, textStatus, jqXHR) {
          if (data) {
            uri = data['uri'];
            description = data['description'];
            if (!description || !uri) {
              return;
            }
            parentDescriptions = new Array();
            for (ii = 0; data['parents'] && ii < data['parents'].length; ii++) {
              parentDescriptions[ii] = data['parents'][ii]['description'];
            }
            parentStr = parentDescriptions.join(' &raquo; ');
            Drupal.Onki.values[uri] = {description: description, title: parentStr};
            callback(uri);
          }
        }
      );
    },

    // nice elements are <span>s for taxonomy terms to show in the admin interface
    // to indicate an article has been tagged with a specific term
    // the ONKI Uri should be parsed to the corresponding title and description for display
    insertNiceElem: function(uri, description) {
      if (!uri) {
        return false;
      }
      labeled = '';
      if (!description) {
        description = Drupal.t('loading') + '...';
      }
      else {
        labeled = 'labeled customTerm';
      }

      $niceElem = $('#onki-nice-term-wrapper');
      delTxt = Drupal.t('Remove');
      button = '<div class="onki-nice-terms" data-value="' + uri + '"><span class="description">' + description + '</span><div class="onki-remove" title="' + delTxt + '">&otimes;</div><span class="title"></span></div>';
      $niceElem.append(button);

      // Create event for the delete buttons.
      $('.onki-remove', $niceElem).click(function() {
        $button = $(this).closest('.onki-nice-terms');
        removableUri = $button.attr('data-value');
        delete Drupal.Onki.values[removableUri];
        // Remove the span element.
        $button.remove();
      });
    },

    updateNiceElems: function(uri) {
      $niceElem = $('#onki-nice-term-wrapper');
      $('.onki-nice-terms[data-value=' + uri + ']:not(.labeled)', $niceElem).each(function() {
        $this = $(this);
        $this.addClass('labeled');
        uri = $this.attr('data-value');
        $('.description', $this).html(Drupal.Onki.values[uri].description);
        $('.title', $this).html(Drupal.Onki.values[uri].title);
      });
    },

    // on submit, transfer all added ONKI URIs from onki.values array to the real (hidden) taxonomy field for submission
    submit: function($realField) {
      keys = new Array();
      for (key in Drupal.Onki.values) {
        keys.push(key);
      }
      $realField.attr('value', keys.join(','));
    },

    fixAutocompleteEvents: function() {
      if (Drupal.jsAC) {
        // this overrides the hidePopup function so it fires a "change" event
        var oldhp = Drupal.jsAC.prototype.hidePopup;
        Drupal.jsAC.prototype.hidePopup = function (keycode) {
          var isselected = this.selected;
          oldhp.call(this, keycode);
          if (isselected) {
            $(this.input).trigger('autocompleteSelect');
          }
        };

        // this overrides the hidePopup function so it fires a "change" event
        var oldselect = Drupal.jsAC.prototype.select;
        Drupal.jsAC.prototype.select = function (node) {
          oldselect.call(this, node);
          $(this.input).trigger('autocompleteSelect');
        };
      }
    }
  }
})(jQuery);

function onkiGetNiceTerms() {
  niceTerms = [];
  jQuery('#onki-nice-term-wrapper [data-value]').each(function(idx, item) {
    niceTerms.push(jQuery(this).attr("data-value"));
  });
  return niceTerms;
}

function countProperties(obj) {
  var count = 0;

  for (var prop in obj) {
    if (obj.hasOwnProperty(prop)) {
      ++count;
    }
  }

  return count;
}
